@@ -21,6 +21,11 @@ xmlrpclib.Marshaller.dispatch[datetime.date] = \
         lambda self, value, write: self.dump_datetime(
                 datetime.datetime.combine(value, datetime.time()), write)
 
+def _end_double(self, data):
+    self.append(Decimal(data))
+    self._value = 0
+xmlrpclib.Unmarshaller.dispatch["double"] = _end_double
+
 _CONFIG = threading.local()
 
 
@@ -44,7 +49,7 @@ class Config(object):
     def __eq__(self, other):
         if isinstance(other, Config):
             return repr(self) == repr(other)
-        return NotImplemented
+        raise NotImplementedError
 
 
 class _TrytondMethod(object):
